@@ -283,7 +283,7 @@ class JenkinsProps:
         :param seed_jobs: List of seed job configuration for Jenkins resource. For more information about seed jobs, please take a look at { @link https://github.com/jenkinsci/job-dsl-plugin/wiki/Tutorial---Using-the-Jenkins-Job-DSL Jenkins Seed Jobs Documentation }. Default: - No seed jobs
         '''
         if isinstance(metadata, dict):
-            metadata = ApiObjectMetadata(**metadata)
+            metadata = cdk8s.ApiObjectMetadata(**metadata)
         if __debug__:
             type_hints = typing.get_type_hints(JenkinsProps.__init__)
             check_type(argname="argument base_plugins", value=base_plugins, expected_type=type_hints["base_plugins"])
